@@ -3,17 +3,20 @@
 
 #include <QtCore>
 
-class BadWordCheck: public QObject {
-Q_OBJECT
+class BadWordCheck: public QObject
+{
+	Q_OBJECT
 public:
-    BadWordCheck();
-	
-	void setBadWords(QStringList bw) { badWords = bw; }
-	
+	BadWordCheck();
+
+	void setBadWords(QStringList bw) {
+		badWords = bw;
+	}
+
 	bool run(QString);
-	
+
 private:
-	
+
 	QStringList badWords;
 };
 
