@@ -2,20 +2,21 @@
 #include "cleanerserver.h"
 
 #ifdef _WIN32
-	#include <process.h>
+#include <process.h>
 #else
-	#include <unistd.h>
-	#ifndef daemon
-		int daemon(int, int);
-	#endif
+#include <unistd.h>
+#ifndef daemon
+int daemon(int, int);
+#endif
 #endif
 
 int main(int argc, char *argv[])
 {
-    QCoreApplication a(argc, argv);
+	QCoreApplication a(argc, argv);
 	CleanerServer server;
 #ifndef _WIN32
-	daemon(0, 0);
+	if (daemon(0, 0) != 0)
+		return -1;
 #endif
-    return a.exec();
+	return a.exec();
 }
