@@ -38,24 +38,30 @@ gameLobbyDialogImpl::gameLobbyDialogImpl(startWindowImpl *parent, ConfigFile *c)
 #ifdef __APPLE__
 	setWindowModality(Qt::ApplicationModal);
 	setWindowFlags(Qt::WindowSystemMenuHint | Qt::CustomizeWindowHint | Qt::Dialog);
+#elif _WIN32
+    setWindowFlags(Qt::Dialog | Qt::WindowMinimizeButtonHint);
 #endif
-	setupUi(this);
 
+    setupUi(this);
 	myAppDataPath = QString::fromUtf8(myConfig->readConfigString("AppDataDir").c_str());
 
 	//wait start game message
-	waitStartGameMsgBox = new QMessageBox(this);
+    waitStartGameMsgBox = new MyMessageBox(this);
 	waitStartGameMsgBox->setText(tr("Starting game. Please wait ..."));
-	waitStartGameMsgBox->setWindowModality(Qt::NonModal);
+#ifndef ANDROID
+    waitStartGameMsgBox->setWindowModality(Qt::NonModal);
+#endif
 #ifdef __APPLE__
 	waitStartGameMsgBox->setWindowFlags(Qt::WindowSystemMenuHint | Qt::CustomizeWindowHint | Qt::Dialog);
 #endif
 	waitStartGameMsgBox->setStandardButtons(QMessageBox::NoButton);
 
 	//wait start game message for rejoin
-	waitRejoinStartGameMsgBox = new QMessageBox(this);
+    waitRejoinStartGameMsgBox = new MyMessageBox(this);
 	waitRejoinStartGameMsgBox->setText(tr("Waiting for the start of the next hand to rejoin the game ..."));
-	waitRejoinStartGameMsgBox->setWindowModality(Qt::NonModal);
+#ifndef ANDROID
+    waitRejoinStartGameMsgBox->setWindowModality(Qt::NonModal);
+#endif
 #ifdef __APPLE__
 	waitRejoinStartGameMsgBox->setWindowFlags(Qt::WindowSystemMenuHint | Qt::CustomizeWindowHint | Qt::Dialog);
 #endif
@@ -110,16 +116,31 @@ gameLobbyDialogImpl::gameLobbyDialogImpl(startWindowImpl *parent, ConfigFile *c)
 	headerList << tr("Game") << tr("Players") << tr("State") << tr("T") << tr("P");
 	myGameListModel->setHorizontalHeaderLabels(headerList);
 
-	treeView_GameList->setColumnWidth(0,190);
-	treeView_GameList->setColumnWidth(1,65);
-	treeView_GameList->setColumnWidth(2,65);
-	treeView_GameList->setColumnWidth(3,40);
-	treeView_GameList->setColumnWidth(4,40);
-
 #ifdef GUI_800x480
-	treeView_GameList->setStyleSheet("QTreeView {background-color: white; background-image: url(\""+myAppDataPath +"gfx/gui/misc/background_gamelist.png\"); background-attachment: fixed; background-position: top center ; background-repeat: no-repeat; color:rgb(0, 0, 0); font: 14px}");
+    treeView_GameList->setColumnWidth(0,220);
+    treeView_GameList->setColumnWidth(1,65);
+    treeView_GameList->setColumnWidth(2,90);
+    treeView_GameList->setColumnWidth(3,30);
+    treeView_GameList->setColumnWidth(4,30);
+
+    treeView_GameList->setStyleSheet("QTreeView {background-color: white; background-image: url(\""+myAppDataPath +"gfx/gui/misc/background_gamelist.png\"); background-attachment: fixed; background-position: top center ; background-repeat: no-repeat; color:rgb(0, 0, 0); font: 22px}");
+    treeView_GameList->header()->setStyleSheet("QObject {font: bold 18px}");
+
+    //make the scrollbars touchable for mobile guis
+    this->setStyleSheet("QScrollBar:vertical { border: 1px solid grey; background: #f0f0f0; width: 55px; margin: 1px -1px 0px 0px; } QScrollBar::handle:vertical { border-radius: 4px; border: 3px solid grey; background: LightGrey ; min-height: 60px; } QScrollBar::add-line:vertical { background: none; } QScrollBar::sub-line:vertical { background: none; } QScrollBar:up-arrow:vertical, QScrollBar::down-arrow:vertical { background: none; } QScrollBar::add-page:vertical, QScrollBar::sub-page:vertical { background: none; }");
+
+    //remove game type in game description field to save space
+    label_gameType->hide();
+    label_typeIcon->hide();
+    label_typeText->hide();
 #else
-	treeView_GameList->setStyleSheet("QTreeView {background-color: white; background-image: url(\""+myAppDataPath +"gfx/gui/misc/background_gamelist.png\"); background-attachment: fixed; background-position: top center ; background-repeat: no-repeat;}");
+    treeView_GameList->setColumnWidth(0,190);
+    treeView_GameList->setColumnWidth(1,65);
+    treeView_GameList->setColumnWidth(2,65);
+    treeView_GameList->setColumnWidth(3,40);
+    treeView_GameList->setColumnWidth(4,40);
+
+    treeView_GameList->setStyleSheet("QTreeView {background-color: white; background-image: url(\""+myAppDataPath +"gfx/gui/misc/background_gamelist.png\"); background-attachment: fixed; background-position: top center ; background-repeat: no-repeat;}");
 #endif
 	treeView_GameList->setAutoFillBackground(TRUE);
 
@@ -212,7 +233,9 @@ void gameLobbyDialogImpl::exec()
 		registeredUserMode();
 	}
 
-
+#ifdef ANDROID
+        this->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
+#endif
 	QDialog::exec();
 
 	waitStartGameMsgBoxTimer->stop();
@@ -397,11 +420,20 @@ void gameLobbyDialogImpl::refresh(int actionID)
 		QStringList headerList;
 		headerList << tr("Game") << tr("Players") << tr("State") << tr("T") << tr("P");
 		myGameListModel->setHorizontalHeaderLabels(headerList);
-		treeView_GameList->setColumnWidth(0,190);
+
+#ifdef GUI_800x480
+        treeView_GameList->setColumnWidth(0,220);
+        treeView_GameList->setColumnWidth(1,65);
+        treeView_GameList->setColumnWidth(2,90);
+        treeView_GameList->setColumnWidth(3,30);
+        treeView_GameList->setColumnWidth(4,30);
+#else
+        treeView_GameList->setColumnWidth(0,190);
 		treeView_GameList->setColumnWidth(1,65);
 		treeView_GameList->setColumnWidth(2,65);
 		treeView_GameList->setColumnWidth(3,40);
 		treeView_GameList->setColumnWidth(4,40);
+#endif
 
 		QStringList headerList2;
 		headerList2 << tr("Available Players");
@@ -790,11 +822,20 @@ void gameLobbyDialogImpl::clearDialog()
 	QStringList headerList;
 	headerList << tr("Game") << tr("Players") << tr("State") << tr("T") << tr("P");
 	myGameListModel->setHorizontalHeaderLabels(headerList);
-	treeView_GameList->setColumnWidth(0,190);
+
+#ifdef GUI_800x480
+    treeView_GameList->setColumnWidth(0,220);
+    treeView_GameList->setColumnWidth(1,65);
+    treeView_GameList->setColumnWidth(2,90);
+    treeView_GameList->setColumnWidth(3,30);
+    treeView_GameList->setColumnWidth(4,30);
+#else
+    treeView_GameList->setColumnWidth(0,190);
 	treeView_GameList->setColumnWidth(1,65);
 	treeView_GameList->setColumnWidth(2,65);
 	treeView_GameList->setColumnWidth(3,40);
 	treeView_GameList->setColumnWidth(4,40);
+#endif
 
 	pushButton_CreateGame->clearFocus();
 	lineEdit_ChatInput->setFocus();
@@ -1253,7 +1294,7 @@ void gameLobbyDialogImpl::kickPlayer()
 		QString playerName = item->text(0);
 		if(playerName == QString::fromUtf8(myConfig->readConfigString("MyName").c_str())) {
 			{
-				QMessageBox::warning(this, tr("Server Error"),
+				MyMessageBox::warning(this, tr("Server Error"),
 									 tr("You should not kick yourself from this game!"),
 									 QMessageBox::Close);
 			}
@@ -1324,7 +1365,9 @@ void gameLobbyDialogImpl::showGameDescription(bool show)
 {
 
 	if(show) {
+#ifndef GUI_800x480
 		label_gameType->show();
+#endif
 		label_gameDesc2->show();
 		label_gameDesc3->show();
 		label_gameDesc4->show();
@@ -1492,8 +1535,10 @@ void gameLobbyDialogImpl::changeGameListFilter(int index)
 	writeDialogSettings(1);
 
 #ifdef GUI_800x480
-	if(index) treeView_GameList->setStyleSheet("QTreeView { border-radius: 4px; border: 2px solid blue; background-color: white; background-image: url(\""+myAppDataPath +"gfx/gui/misc/background_gamelist.png\"); background-attachment: fixed; background-position: top center ; background-repeat: no-repeat; color:rgb(0, 0, 0); font: 14px}");
-	else treeView_GameList->setStyleSheet("QTreeView { background-color: white; background-image: url(\""+myAppDataPath +"gfx/gui/misc/background_gamelist.png\"); background-attachment: fixed; background-position: top center ; background-repeat: no-repeat; color:rgb(0, 0, 0); font: 14px}");
+        if(index) treeView_GameList->setStyleSheet("QTreeView { border-radius: 4px; border: 2px solid blue; background-color: white; background-image: url(\""+myAppDataPath +"gfx/gui/misc/background_gamelist.png\"); background-attachment: fixed; background-position: top center ; background-repeat: no-repeat; color:rgb(0, 0, 0); font: 20px}");
+        else treeView_GameList->setStyleSheet("QTreeView { background-color: white; background-image: url(\""+myAppDataPath +"gfx/gui/misc/background_gamelist.png\"); background-attachment: fixed; background-position: top center ; background-repeat: no-repeat; color:rgb(0, 0, 0); font: 20px}");
+
+        treeView_GameList->header()->setStyleSheet("QObject {font: bold 18px}");
 #else
 	if(index) treeView_GameList->setStyleSheet("QTreeView { border-radius: 4px; border: 2px solid blue; background-color: white; background-image: url(\""+myAppDataPath +"gfx/gui/misc/background_gamelist.png\"); background-attachment: fixed; background-position: top center ; background-repeat: no-repeat;}");
 	else treeView_GameList->setStyleSheet("QTreeView { background-color: white; background-image: url(\""+myAppDataPath +"gfx/gui/misc/background_gamelist.png\"); background-attachment: fixed; background-position: top center ; background-repeat: no-repeat;}");
@@ -1707,7 +1752,13 @@ void gameLobbyDialogImpl::showAutoStartTimer()
 	autoStartTimerOverlay->setGeometry(((scrollArea_gameInfos->geometry().width()-190)/2), ((scrollArea_gameInfos->geometry().height()-50)/2), 190, 50);
 
 	QString string(tr("The game will start in<br><b>%1</b> seconds.").arg(6));
-	autoStartTimerOverlay->setText("<span style='color:#008B00; font-size:9pt;'>"+string+"</span>");
+        QString fontsize;
+#ifdef ANDROID
+        fontsize="16px";
+#else
+        fontsize="10px";
+#endif
+        autoStartTimerOverlay->setText("<span style='color:#008B00; font-size:"+fontsize+";'>"+string+"</span>");
 	autoStartTimerCounter = 6;
 	autoStartTimer->start(1000);
 
@@ -1718,7 +1769,13 @@ void gameLobbyDialogImpl::updateAutoStartTimer()
 	--autoStartTimerCounter;
 	if(autoStartTimerCounter) {
 		QString string(tr("The game will start in<br><b>%1</b> seconds.").arg(autoStartTimerCounter));
-		autoStartTimerOverlay->setText("<span style='color:#008B00; font-size:9pt;'>"+string+"</span>");
+                QString fontsize;
+#ifdef ANDROID
+                fontsize="16px";
+#else
+                fontsize="10px";
+#endif
+                autoStartTimerOverlay->setText("<span style='color:#008B00; font-size:"+fontsize+";'>"+string+"</span>");
 	} else {
 		autoStartTimer->stop();
 		autoStartTimerOverlay->hide();
@@ -2045,7 +2102,7 @@ void gameLobbyDialogImpl::reportBadGameName()
 		unsigned gameId = selection->selectedRows().first().data(Qt::UserRole).toUInt();
 		GameInfo info(mySession->getClientGameInfo(gameId));
 
-		int ret = QMessageBox::question(this, tr("PokerTH - Question"),
+		int ret = MyMessageBox::question(this, tr("PokerTH - Question"),
 										tr("Are you sure you want to report the game name:\n\"%1\" as inappropriate?").arg(QString::fromUtf8(info.name.c_str())), QMessageBox::Yes | QMessageBox::No);
 
 		if(ret == QMessageBox::Yes) {
