@@ -45,7 +45,9 @@ void MyActionButton::paintEvent(QPaintEvent * event)
 	if(objectName()==("pushButton_AllIn")) {
 		painter.drawText(6,6,15,15,Qt::AlignLeft,fKeyText);
 	} else if(objectName()==("pushButton_showMyCards")) {
+#ifndef GUI_800x480
 		painter.drawText(6,6,15,15,Qt::AlignLeft,QString("F5"));
+#endif
 	} else {
 		painter.drawText(8,15,15,15,Qt::AlignLeft,fKeyText);
 	}
