@@ -39,6 +39,13 @@ settingsDialogImpl::settingsDialogImpl(QWidget *parent, ConfigFile *c, selectAva
 #endif
 	setupUi(this);
 
+#ifdef ANDROID
+    stackedWidget->removeWidget(page_styles);
+    stackedWidget->removeWidget(page_sound);
+    listWidget->takeItem(1);
+    listWidget->takeItem(1);
+#endif
+
 	if(!SQLITE_LOG) {//temporarely remove sql log features
 		pushButton_deleteLog->hide();
 		pushButton_saveLogAs->hide();
@@ -140,6 +147,11 @@ settingsDialogImpl::settingsDialogImpl(QWidget *parent, ConfigFile *c, selectAva
 	connect( pushButton_saveLogAs, SIGNAL(clicked()), this, SLOT (saveLogFileAs()));
 	connect( treeWidget_logFiles, SIGNAL(currentItemChanged(QTreeWidgetItem*, QTreeWidgetItem*)), this, SLOT(showLogFilePreview()));
 
+#ifdef GUI_800x480
+    //make the scrollbar touchable for mobile guis
+    comboBox_switchLanguage->setStyleSheet("QObject {font: 30px} QScrollBar:vertical { border: 1px solid grey; background: white; width: 60px; margin: 0px -1px 0px 0px; } QScrollBar::handle:vertical { border-radius: 3px; border: 2px solid grey; background: LightGrey ; min-height: 60px; } QScrollBar::add-line:vertical { background: none; } QScrollBar::sub-line:vertical { background: none; } QScrollBar:up-arrow:vertical, QScrollBar::down-arrow:vertical { background: none; } QScrollBar::add-page:vertical, QScrollBar::sub-page:vertical { background: none; }");
+#endif
+
 }
 
 settingsDialogImpl::~settingsDialogImpl()
@@ -276,16 +288,21 @@ void settingsDialogImpl::prepareDialog()
 #ifdef GUI_800x480
 	// 	define PokerTH default GameTableStyle for Maemo
 	treeWidget_gameTableStyles->clear();
-
+        QString filename;
+#ifdef MAEMO
+        filename = "defaulttablestyle_800x480.xml";
+#elif ANDROID
+        filename = "android_tablestyle_800x480.xml";
+#endif
 	GameTableStyleReader defaultTableStyle(myConfig, this);
-	defaultTableStyle.readStyleFile(QString::fromUtf8(myConfig->readConfigString("AppDataDir").c_str())+"gfx/gui/table/default_800x480/defaulttablestyle_800x480.xml");
+        defaultTableStyle.readStyleFile(QString::fromUtf8(myConfig->readConfigString("AppDataDir").c_str())+"gfx/gui/table/default_800x480/"+filename);
 	if(defaultTableStyle.getLoadedSuccessfull()) {
 		QStringList tempStringList1;
 		tempStringList1 << defaultTableStyle.getStyleDescription() << defaultTableStyle.getStyleMaintainerName();
 		MyStyleListItem *defaultTableItem = new MyStyleListItem(tempStringList1, treeWidget_gameTableStyles);
-		defaultTableItem->setData(0, 15, QString::fromUtf8(myConfig->readConfigString("AppDataDir").c_str())+"gfx/gui/table/default_800x480/defaulttablestyle_800x480.xml");
+                defaultTableItem->setData(0, 15, QString::fromUtf8(myConfig->readConfigString("AppDataDir").c_str())+"gfx/gui/table/default_800x480/"+filename);
 		defaultTableItem->setData(0, 16, POKERTH_DISTRIBUTED_STYLE);
-		defaultTableItem->setData(0, Qt::ToolTipRole, QString::fromUtf8(myConfig->readConfigString("AppDataDir").c_str())+"gfx/gui/table/default_800x480/defaulttablestyle_800x480.xml");
+                defaultTableItem->setData(0, Qt::ToolTipRole, QString::fromUtf8(myConfig->readConfigString("AppDataDir").c_str())+"gfx/gui/table/default_800x480/"+filename);
 		defaultTableItem->setData(2, Qt::ToolTipRole, defaultTableStyle.getMyStateToolTipInfo());
 		if(defaultTableStyle.getState()) defaultTableItem->setIcon(2, QIcon(":/gfx/emblem-important.png"));
 		else defaultTableItem->setIcon(2, QIcon(":/gfx/dialog_ok_apply.png"));
@@ -379,6 +396,20 @@ void settingsDialogImpl::prepareDialog()
 	showCurrentGameTableStylePreview();
 
 	//CARDS
+#ifdef GUI_800x480
+    // 	define PokerTH default GameTableStyle for Maemo
+    treeWidget_cardDeckStyles->clear();
+    CardDeckStyleReader defaultCardStyle(myConfig, this);
+    defaultCardStyle.readStyleFile(QString::fromUtf8(myConfig->readConfigString("AppDataDir").c_str())+"gfx/cards/default_800x480/defaultdeckstyle_800x480.xml");
+    if(defaultCardStyle.getLoadedSuccessfull()) {
+        QStringList tempStringList1;
+        tempStringList1 << defaultCardStyle.getStyleDescription() << defaultCardStyle.getStyleMaintainerName();
+        MyStyleListItem *defaultCardItem = new MyStyleListItem(tempStringList1, treeWidget_cardDeckStyles);
+        defaultCardItem->setData(0, 15, QString::fromUtf8(myConfig->readConfigString("AppDataDir").c_str())+"gfx/cards/default_800x480/defaultdeckstyle_800x480.xml");
+        defaultCardItem->setData(0, 16, POKERTH_DISTRIBUTED_STYLE);
+        defaultCardItem->setData(0, Qt::ToolTipRole, QString::fromUtf8(myConfig->readConfigString("AppDataDir").c_str())+"gfx/cards/default_800x480/defaultdeckstyle_800x480.xml");
+    }
+#else
 	//define PokerTH default CardDeck
 	treeWidget_cardDeckStyles->clear();
 	CardDeckStyleReader defaultCardStyle(myConfig, this);
@@ -399,10 +430,10 @@ void settingsDialogImpl::prepareDialog()
 		tempStringList1 << default4cCardStyle.getStyleDescription() << default4cCardStyle.getStyleMaintainerName();
 		MyStyleListItem *default4cCardItem = new MyStyleListItem(tempStringList1, treeWidget_cardDeckStyles);
 		default4cCardItem->setData(0, 15, QString::fromUtf8(myConfig->readConfigString("AppDataDir").c_str())+"gfx/cards/default4c/default4cdeckstyle.xml");
-		default4cCardItem->setData(0, 16, POKERTH_DISTRIBUTED_STYLE);
+        default4cCardItem->setData(0, 16, POKERTH_DISTRIBUTED_STYLE);
 		default4cCardItem->setData(0, Qt::ToolTipRole, QString::fromUtf8(myConfig->readConfigString("AppDataDir").c_str())+"gfx/cards/default4c/default4cdeckstyle.xml");
 	}
-
+#endif
 	//load secondary card styles into list (if fallback no entry)
 	myCardDeckStylesList = myConfig->readConfigStringList("CardDeckStylesList");
 	list<std::string>::iterator it2;
@@ -530,7 +561,6 @@ void settingsDialogImpl::exec(bool in_game)
 	calledIngame = in_game;
 	prepareDialog();
 	QDialog::exec();
-
 }
 
 void settingsDialogImpl::isAccepted()
@@ -553,7 +583,7 @@ void settingsDialogImpl::isAccepted()
 	checkSetPlayerNicks.insert(lineEdit_Opponent9Name->text().trimmed());
 
 	if(checkSetPlayerNicks.count() != 10) {
-		QMessageBox::warning(this, tr("Settings Error"),
+		MyMessageBox::warning(this, tr("Settings Error"),
 							 tr("The opponent names are not unique.\n"
 								"Please choose different names for each Opponent!"),
 							 QMessageBox::Ok);
@@ -634,7 +664,7 @@ void settingsDialogImpl::isAccepted()
 
 			myConfig->writeConfigString("InternetServerListAddress", lineEdit_InternetServerListAddress->text().toUtf8().constData());
 		} else {
-			QMessageBox::warning(this, tr("Settings Error"),
+			MyMessageBox::warning(this, tr("Settings Error"),
 								 tr("The entered server list address is not a valid URL.\n"
 									"Please enter a valid server list address!"),
 								 QMessageBox::Ok);
@@ -696,7 +726,7 @@ void settingsDialogImpl::isAccepted()
 		if(ownFlipsideFilename.exists() && lineEdit_OwnFlipsideFilename->text() != "") {
 			myConfig->writeConfigString("FlipsideOwnFile", lineEdit_OwnFlipsideFilename->text().toUtf8().constData());
 		} else {
-			QMessageBox::warning(this, tr("Settings Error"),
+			MyMessageBox::warning(this, tr("Settings Error"),
 								 tr("The entered flipside picture doesn't exist.\n"
 									"Please enter an valid picture!"),
 								 QMessageBox::Ok);
@@ -756,7 +786,7 @@ void settingsDialogImpl::isAccepted()
 		if(logDir.exists() && lineEdit_logDir->text() != "") {
 			myConfig->writeConfigString("LogDir", lineEdit_logDir->text().toUtf8().constData());
 		} else {
-			QMessageBox::warning(this, tr("Settings Error"),
+			MyMessageBox::warning(this, tr("Settings Error"),
 								 tr("The log file directory doesn't exist.\n"
 									"Please select an valid directory!"),
 								 QMessageBox::Ok);
@@ -786,7 +816,7 @@ void settingsDialogImpl::isAccepted()
 	myConfig->writeBuffer();
 
 	if(languageIsChanged) {
-		QMessageBox::information(this, tr("Language Changed"),
+		MyMessageBox::information(this, tr("Language Changed"),
 								 tr("You have changed application language to %1.\nPlease restart PokerTH to load new language!").arg(comboBox_switchLanguage->itemText(changedLanguageIndex)),
 								 QMessageBox::Ok);
 	}
@@ -926,12 +956,12 @@ void settingsDialogImpl::setLogDir()
 		if(logDir.exists()) {
 			lineEdit_logDir->setText(dir);
 			refreshLogFileList();
-			QMessageBox::information(this, tr("Settings Information"),
+			MyMessageBox::information(this, tr("Settings Information"),
 									 tr("You have changed the log file directory.\n"
 										"Please restart PokerTH to use the new directory for the log files!"),
 									 QMessageBox::Ok);
 		} else {
-			QMessageBox::warning(this, tr("Settings Error"),
+			MyMessageBox::warning(this, tr("Settings Error"),
 								 tr("The log file directory doesn't exist.\n"
 									"Please select an valid directory!"),
 								 QMessageBox::Ok);
@@ -1034,7 +1064,7 @@ void settingsDialogImpl::setFirstSmallBlindMargin()
 
 	if(radioButton_manualBlindsOrder->isChecked() && !myManualBlindsList.empty()) {
 		if(spinBox_firstSmallBlind->value() > myManualBlindsList.front()) {
-			QMessageBox::warning(this, tr("Blinds Error"),
+			MyMessageBox::warning(this, tr("Blinds Error"),
 								 tr("The first element in your manual-blinds-list \nis smaller than current first-small-blind!\nThis first-small-blind-value will be set to maximum allowed value."),
 								 QMessageBox::Close);
 		}
@@ -1044,7 +1074,7 @@ void settingsDialogImpl::setFirstSmallBlindMargin()
 	}
 	if(radioButton_netManualBlindsOrder->isChecked() && !myNetManualBlindsList.empty()) {
 		if(spinBox_netFirstSmallBlind->value() > myNetManualBlindsList.front()) {
-			QMessageBox::warning(this, tr("Blinds Error"),
+			MyMessageBox::warning(this, tr("Blinds Error"),
 								 tr("The first element in your manual-blinds-list \nis smaller than current first-small-blind!\nThis first-small-blind-value will be set to maximum allowed value."),
 								 QMessageBox::Close);
 		}
@@ -1162,7 +1192,7 @@ void settingsDialogImpl::addGameTableStyle()
 		}
 
 		if(fileNameAlreadyFound) {
-			QMessageBox::warning(this, tr("Game Table Style Error"),
+			MyMessageBox::warning(this, tr("Game Table Style Error"),
 								 tr("Selected game table style file is already in the list. \nPlease select another one to add!"),
 								 QMessageBox::Ok);
 		} else {
@@ -1185,7 +1215,7 @@ void settingsDialogImpl::addGameTableStyle()
 				qDebug() << "settings: " << newStyle.getStyleDescription() << newStyle.getState();
 				if(newStyle.getState() != GT_STYLE_OK) newStyle.showErrorMessage();
 			} else {
-				QMessageBox::warning(this, tr("Game Table Style File Error"),
+				MyMessageBox::warning(this, tr("Game Table Style File Error"),
 									 tr("Could not load game table style file correctly. \nStyle will not be placed into list!"),
 									 QMessageBox::Ok);
 			}
@@ -1288,7 +1318,7 @@ void settingsDialogImpl::addCardDeckStyle()
 		}
 
 		if(fileNameAlreadyFound) {
-			QMessageBox::warning(this, tr("Card Deck Style Error"),
+			MyMessageBox::warning(this, tr("Card Deck Style Error"),
 								 tr("Selected card deck style file is already in the list. \nPlease select another one to add!"),
 								 QMessageBox::Ok);
 		} else {
@@ -1305,7 +1335,7 @@ void settingsDialogImpl::addCardDeckStyle()
 				treeWidget_cardDeckStyles->setCurrentItem(newItem);
 				treeWidget_cardDeckStyles->sortItems(0, Qt::AscendingOrder);
 			} else {
-				QMessageBox::warning(this, tr("Card Deck Style File Error"),
+				MyMessageBox::warning(this, tr("Card Deck Style File Error"),
 									 tr("Could not load card deck style file correctly. \nStyle will not be placed into list!"),
 									 QMessageBox::Ok);
 			}
@@ -1374,7 +1404,7 @@ void settingsDialogImpl::deleteLogFile()
 
 	if(!selectedItemsList.isEmpty() && !( selectedItemsList.size() == 1 && selectedItemsList.front()->data(0, Qt::UserRole+1).toString() == "current" )) {
 
-		int ret = QMessageBox::warning(this, tr("PokerTH - Delete log files"),
+		int ret = MyMessageBox::warning(this, tr("PokerTH - Delete log files"),
 									   tr("Do you really want to delete the selected log files?"),
 									   QMessageBox::Yes | QMessageBox::No);
 
@@ -1383,7 +1413,7 @@ void settingsDialogImpl::deleteLogFile()
 				if(selectedItemsList.at(i)->data(0, Qt::UserRole+1).toString() != "current") {
 
 					if(!QFile::remove(selectedItemsList.at(i)->data(0, Qt::UserRole).toString())) {
-						QMessageBox::warning(this, "Remove log file", "PokerTH cannot remove this log file, please verify that you have write access to this file!", QMessageBox::Close );
+						MyMessageBox::warning(this, "Remove log file", "PokerTH cannot remove this log file, please verify that you have write access to this file!", QMessageBox::Close );
 					}
 				}
 			}
@@ -1455,7 +1485,7 @@ void settingsDialogImpl::showLogFilePreview()
 
 void settingsDialogImpl::resetSettings()
 {
-	int ret = QMessageBox::warning(this, tr("PokerTH - Settings"),
+	int ret = MyMessageBox::warning(this, tr("PokerTH - Settings"),
 								   tr("Attention: this will delete all your personal settings and close PokerTH!\n"
 									  "Do you really want to reset factory settings?"),
 								   QMessageBox::Yes | QMessageBox::No);
