@@ -20,6 +20,7 @@
 #include <sstream>
 #include <cstdlib>
 #include <fstream>
+#include "mymessagebox.h"
 #include "game_defs.h"
 
 using namespace std;
@@ -36,7 +37,11 @@ CardDeckStyleReader::~CardDeckStyleReader()
 
 void CardDeckStyleReader::readStyleFile(QString file)
 {
-
+#ifdef ANDROID
+//on Android we use just the defaul style packed with the binary via qrc
+    currentFileName = ":/android/android-data/gfx/cards/default_800x480/defaultdeckstyle_800x480.xml";
+    currentDir = ":/android/android-data/gfx/cards/default_800x480/";
+#else
 	//if style file failed --> default style fallback
 	if(QFile(file).exists()) {
 		currentFileName = file;
@@ -45,12 +50,12 @@ void CardDeckStyleReader::readStyleFile(QString file)
 		fallBack = 1;
 	}
 
-	QFile myFile(currentFileName);
-	myFile.open(QIODevice::ReadOnly);
-	fileContent = myFile.readAll();
-
 	QFileInfo info(currentFileName);
 	currentDir = info.absolutePath()+"/";
+#endif
+        QFile myFile(currentFileName);
+        myFile.open(QIODevice::ReadOnly);
+        fileContent = myFile.readAll();
 
 	//start reading the file and fill vars
 	string tempString1("");
@@ -63,7 +68,7 @@ void CardDeckStyleReader::readStyleFile(QString file)
 
 		TiXmlElement *GameTableElement = docHandle.FirstChild( "PokerTH" ).FirstChild( "TableStyle" ).ToElement();
 		if(GameTableElement) {
-			QMessageBox::warning(myW, tr("Card Deck Style Error"),
+			MyMessageBox::warning(myW, tr("Card Deck Style Error"),
 								 tr("A game table style was selected instead of a card deck style.\nPlease select a card deck style and try again!"),
 								 QMessageBox::Ok);
 		} else {
@@ -134,7 +139,7 @@ void CardDeckStyleReader::readStyleFile(QString file)
 				if(PokerTHStyleFileVersion != "" && PokerTHStyleFileVersion.toInt() != POKERTH_CD_STYLE_FILE_VERSION) {
 					QString EMail;
 					if(StyleMaintainerEMail != "NULL") EMail = StyleMaintainerEMail;
-					QMessageBox::warning(myW, tr("Card Deck Style Error"),
+					MyMessageBox::warning(myW, tr("Card Deck Style Error"),
 										 tr("Selected card deck style \"%1\" seems to be outdated. \n The current PokerTH card deck style version is \"%2\", but this style has version \"%3\" set. \n\nPlease contact the card deck style builder %4.").arg(StyleDescription).arg(POKERTH_CD_STYLE_FILE_VERSION).arg(PokerTHStyleFileVersion).arg(EMail),
 										 QMessageBox::Ok);
 				}
@@ -142,7 +147,7 @@ void CardDeckStyleReader::readStyleFile(QString file)
 		}
 	} else {
 		loadedSuccessfull = 0;
-		QMessageBox::warning(myW, tr("Card Deck Style Error"),
+		MyMessageBox::warning(myW, tr("Card Deck Style Error"),
 							 tr("Cannot load card deck style file: %1 \n\nPlease check the style file or choose another style!").arg(currentFileName),
 							 QMessageBox::Ok);
 	}
@@ -155,7 +160,7 @@ void CardDeckStyleReader::showLeftItemsErrorMessage(QString style, QStringList f
 	QString EMail;
 	if(email != "NULL") EMail = email;
 
-	QMessageBox::warning(myW, tr("Card Deck Style Error"),
+	MyMessageBox::warning(myW, tr("Card Deck Style Error"),
 						 tr("Selected card deck style \"%1\" seems to be incomplete or defective. \n\nThe value(s) of \"%2\" is/are missing. \n\nPlease contact the card deck style builder %3.").arg(style).arg(items).arg(EMail),
 						 QMessageBox::Ok);
 }
@@ -166,7 +171,7 @@ void CardDeckStyleReader::showCardsLeftErrorMessage(QString style, QStringList f
 	QString EMail;
 	if(email != "NULL") EMail = email;
 
-	QMessageBox::warning(myW, tr("Card Deck Style Error"),
+	MyMessageBox::warning(myW, tr("Card Deck Style Error"),
 						 tr("Selected card deck style \"%1\" seems to be incomplete or defective. \nThe card picture(s) \"%2\" is/are not available. \n\nPlease contact the card deck style builder %3.").arg(style).arg(items).arg(EMail),
 						 QMessageBox::Ok);
 }
