@@ -938,13 +938,15 @@ ServerLobbyThread::HandlePacket(boost::shared_ptr<SessionData> session, boost::s
 					HandleNetPacketJoinGame(session, joinRequest->autoLeave, joinRequest->joinGameAction.choice.joinExistingGame);
 				else if (joinRequest->joinGameAction.present == joinGameAction_PR_rejoinExistingGame)
 					HandleNetPacketRejoinGame(session, joinRequest->autoLeave, joinRequest->joinGameAction.choice.rejoinExistingGame);
-			} else if (packet->GetMsg()->present == PokerTHMessage_PR_chatRequestMessage)
+			} else if (packet->GetMsg()->present == PokerTHMessage_PR_chatRequestMessage) {
 				HandleNetPacketChatRequest(session, packet->GetMsg()->choice.chatRequestMessage);
-			else if (packet->GetMsg()->present == PokerTHMessage_PR_rejectGameInvitationMessage)
+			} else if (packet->GetMsg()->present == PokerTHMessage_PR_rejectGameInvitationMessage) {
 				HandleNetPacketRejectGameInvitation(session, packet->GetMsg()->choice.rejectGameInvitationMessage);
-			else if (packet->GetMsg()->present == PokerTHMessage_PR_reportGameMessage)
+			} else if (packet->GetMsg()->present == PokerTHMessage_PR_reportGameMessage) {
 				HandleNetPacketReportGame(session, packet->GetMsg()->choice.reportGameMessage);
-			else
+			} else if (packet->GetMsg()->present == PokerTHMessage_PR_leaveGameRequestMessage) {
+				// Ignore "leave game" in this state.
+			} else
 				SessionError(session, ERR_SOCK_INVALID_STATE);
 		}
 	}
@@ -1446,8 +1448,10 @@ ServerLobbyThread::HandleNetPacketRejectGameInvitation(boost::shared_ptr<Session
 		ServerGame &game = *pos->second;
 		unsigned tmpPlayerId = session->GetPlayerData()->GetUniqueId();
 		if (game.IsPlayerInvited(tmpPlayerId)) {
-			// If he rejects, he is no longer invited.
-			game.RemovePlayerInvitation(tmpPlayerId);
+			// If he actively rejects, he is no longer invited.
+			if (reject.myRejectReason == RejectGameInvReason_no) {
+				game.RemovePlayerInvitation(tmpPlayerId);
+			}
 			// Send reject notification.
 			boost::shared_ptr<NetPacket> packet(new NetPacket(NetPacket::Alloc));
 			packet->GetMsg()->present = PokerTHMessage_PR_rejectInvNotifyMessage;
